@@ -1,6 +1,20 @@
-use async_trait::async_trait;
-use messagebus::{error::Error, receivers, AsyncBatchHandler, BatchHandler, Bus};
+use std::sync::Arc;
 
+use async_trait::async_trait;
+use messagebus::{receivers, AsyncBatchHandler, BatchHandler, Message, error, Bus};
+use thiserror::Error;
+
+#[derive(Debug, Error, Clone)]
+enum Error {
+    #[error("Error({0})")]
+    Error(Arc<anyhow::Error>)
+}
+
+impl<M: Message> From<error::Error<M>> for Error {
+    fn from(err: error::Error<M>) -> Self {
+        Self::Error(Arc::new(err.into()))
+    }
+}
 struct TmpReceiver;
 
 #[async_trait]
@@ -29,12 +43,12 @@ impl BatchHandler<i16> for TmpReceiver {
 async fn main() {
     let (b, poller) = Bus::build()
         .register(TmpReceiver)
-        .subscribe::<i32, receivers::BufferUnorderedBatchedAsync<_>, _, _>(16, Default::default())
-        .subscribe::<i16, receivers::BufferUnorderedBatchedSync<_>, _, _>(16, Default::default())
+        .subscribe::<i32, receivers::BufferUnorderedBatchedAsync<_, _, _>, _, _>(16, Default::default())
+        .subscribe::<i16, receivers::BufferUnorderedBatchedSync<_, _, _>, _, _>(16, Default::default())
         .done()
         .build();
 
-    for i in 1..100 {
+    for i in 1..100i32 {
         b.send(i).await.unwrap();
     }
 
